@@ -1,5 +1,5 @@
 
-tryCatch(utils::globalVariables(c('rot','elev','slider','manipulate','colorList')), 
+tryCatch(utils::globalVariables(c('slider','picker','button','checkbox','rot','elev','slider','manipulate','colorList')), 
 		 error=function(e) message('Looks like you should update R.'))
 
 #' Plotting mathematical expressions
@@ -19,7 +19,7 @@ tryCatch(utils::globalVariables(c('rot','elev','slider','manipulate','colorList'
 #' @param xlab label for x axis
 #' @param ylab label for y axis
 #' @param zlab label for z axis (when in surface-plot mode)
-#' @param col color for line graphs and contours
+#' @param col vector of colors for line graphs and contours
 #' @param filled fill with color between the contours (\code{TRUE} by default)
 #' @param levels levels at which to draw contours
 #' @param nlevels number of contours to draw (if \code{levels} not specified)
@@ -64,7 +64,7 @@ tryCatch(utils::globalVariables(c('rot','elev','slider','manipulate','colorList'
 #' plotFun( sin(x) ~ x, 
 #'    groups=cut(x, findZeros(sin(x) ~ x, within=10)$x), 
 #'    col=c('blue','green'), lty=2, lwd=3, xlim=c(-10,10) )
-#' plotFun( sin(2*pi*x/P)*exp(-k*t)~x+t,k=2,P=.3)
+#' ## plotFun( sin(2*pi*x/P)*exp(-k*t)~x+t, k=2, P=.3)
 #' f <- rfun( ~ u & v )
 #' plotFun( f(u=u,v=v) ~ u & v, u.lim=range(-3,3), v.lim=range(-3,3) )
 #' plotFun( u^2 + v < 3 ~ u & v, add=TRUE, npts=200 )
@@ -86,6 +86,7 @@ plotFun <- function(object, ...,
 					levels=NULL, nlevels=10,labels=TRUE,
 					surface=FALSE,
 					groups=NULL,
+          col = trellis.par.get('superpose.line')$col,
 					col.regions=topo.colors, 
 					type="l", 
 					alpha=NULL ) { 
@@ -95,28 +96,23 @@ plotFun <- function(object, ...,
 		formula[[2]] <- as.call( list(substitute(object), quote(x)))
 		object <- formula
 	}
-
-	if ( is.vector(col.regions ) ) col.regions  <- makeColorscheme(col.regions )
-
-  if (length(unique(levels))==1) levels = c(levels,Inf) #make sure there's a range
-	if (add) { 
-		ladd( panel.plotFun( object, npts=npts, # lwd=lwd, #col=col, 
-							filled=filled, levels=levels, nlevels=nlevels, surface=surface, 
-							col.regions=col.regions, type=type, alpha=alpha, ...))
-		return(invisible(NULL))
-	} 
-
+  
 	dots <- list(...)
-	dots[['type']] <- type
-	dots[['alpha']] <- alpha
+	# dots[['type']] <- type
+	# dots[['alpha']] <- alpha
+	
+	..f.. <- do.call( "makeFun", c(object, dots, strict.declaration=FALSE), envir= parent.frame()) 
 
+  if ( is.vector(col.regions ) ) col.regions  <- makeColorscheme(col.regions )
+
+  if (length(unique(levels))==1) levels = c(levels,Inf) # make sure there's a range
+	
 	# funny names (like ..f..) are to avoid names that might be used by the user
 	# not sure whether this precaution is necessary in current implementation
 
-	# perhaps use environment(object)?
-	..f.. <- do.call( "makeFun", c(object, dots, strict.declaration=FALSE), envir= parent.frame())  
-
 	vars <- formals(..f..)
+  # print(formals(..f..))
+  # print(..f..)
 	rhsVars <- all.vars(rhs(object))
 	otherVars <- setdiff(names(vars), rhsVars)
 	ndims <- length(rhsVars)
@@ -125,9 +121,47 @@ plotFun <- function(object, ...,
 		cleanDots[[v]] <- NULL
 	}
 
+  pgArgs <- list()
+  # print(otherVars)
+  otherGroups <- if (length(otherVars) > 0 ) paste(otherVars,"",sep="") else c()
+  if (length( setdiff( otherGroups, names(dots) ) ) > 0 ) {
+    # print(list(otherGroups=otherGroups, dots=names(dots)) )
+    stop(paste("Cannot plot with free parameters; try setting", 
+               paste( setdiff(otherGroups, names(dots)), collapse=", " ) ))
+  }
+  for (param in otherVars) pgArgs[[param]] <- dots[[paste(param,"",sep="")]]
+  paramGrid <- do.call( "expand.grid", pgArgs )
+  
+	fList <- if (nrow(paramGrid) < 1) list(..f..) else list()
+	for (r in rows(paramGrid) ) {
+    rowAsList <- as.list( paramGrid[r,])
+    names(rowAsList) <- otherVars
+    # print( c( object, c(dots, rowAsList, strict.declaration=FALSE) ) )
+	  fList <- c( fList, do.call ( "makeFun", 
+	                               c( object, c(dots, rowAsList,
+	                                           strict.declaration=FALSE, envir= parent.frame()) ) 
+	  ))
+	}
+
+
+	if (add) { 
+		if (ndims==1) {
+			ladd( panel.plotFun1( fList, npts=npts, # lwd=lwd, #col=col, 
+								 filled=filled, levels=levels, nlevels=nlevels, surface=surface, 
+								 col.regions=col.regions, type=type, alpha=alpha, col=col, ...))
+			return(invisible(NULL))
+		}
+		# message("2-D adding temporarily un-discontinued.")
+		ladd( panel.plotFun( object, npts=npts, # lwd=lwd, #col=col, 
+		                     filled=filled, levels=levels, nlevels=nlevels, surface=surface, 
+		                     col.regions=col.regions, type=type, alpha=alpha, ...))
+		return(invisible(NULL))
+	} 
+	
 	limits <- inferArgs( dots=dots, vars=rhsVars, defaults=list(xlim=xlim, ylim=ylim) )
 
 	if( ndims == 1 ){
+		# message("One Dimension.")
 
 		npts <- ifelse( is.null(npts), 200, npts)
 
@@ -136,16 +170,17 @@ plotFun <- function(object, ...,
 
 		if( is.null(ylab) ) ylab <- deparse( lhs(object) ) # deparse(..f..$sexpr)
 		if( is.null(xlab) ) xlab <- rhsVars
-    
+
+    # need to handle range detection for list of functions
 		if (is.null(limits$xlim) || length(limits$xlim) < 2 ) {
       zeros <- c() #empty
       tryCatch( zeros <- findZeros( object, nearest=6, ... )[[1]], 
                 error=function(e){e},warning=function(e){} )
-			limits$xlim <- switch(as.character(length(zeros)), 
-				"0" = c(0,1),
-				"1" = c(-1.5,1.5) * (zeros+ifelse(zeros==0,1,0)),
-				( c(-.1,.1) * diff(range(zeros)) ) + range(zeros)
-			)
+      limits$xlim <- switch(as.character(length(zeros)), 
+                            "0" = c(0,1),
+                            "1" = c(-1.5,1.5) * (zeros+ifelse(zeros==0,1,0)),
+                            c(-.1,.1) * diff(range(zeros)) + range(zeros)
+      )
 		} 
 
 		limits$xlim <- range(limits$xlim)
@@ -153,50 +188,56 @@ plotFun <- function(object, ...,
 		if (length(limits$xlim) !=2) stop ("Invalid limits.")
 
 		# Evaluate the function on appropriate inputs.
+    .f. <- fList[[1]]
 		.xvals <- 
 			if ('h' %in% type)  
 				seq(min(limits$xlim), max(limits$xlim), length.out=npts)
 			else 
-				mosaic::adapt_seq(min(limits$xlim), max(limits$xlim), 
-										   f=function(xxqq){ ..f..(xxqq) }, length=npts)
-		
-		.yvals <- sapply( .xvals, ..f.. )  # pfun(.xvals)
-		localData <- data.frame(.xvals, .yvals, .xvals, .yvals)
-		names(localData) <- c("x", "y", rhsVars, paste('f(',rhsVars,')',sep=''))
+				adapt_seq(min(limits$xlim), max(limits$xlim), 
+										   f=function(xxqq){ .f.(xxqq) }, length.out=npts)
+	
+    .yvals <- c()
+    for ( .f. in fList ) .yvals <- c( .yvals, sapply( .xvals, .f. ) )
+		localData <- data.frame(x = range(.xvals), y = range(.yvals))
 
 		# note: passing ... through to the lattice functions currently conflicts with
 		# using ... to set values of "co-variates" of the function.
-		# print(cleanDots)
+
 		if( length(limits$ylim) != 2 ) {
+    
 			thePlot <- do.call(lattice::xyplot,
-							 c(list(y ~ x, 
+							 c( list(y ~ x, 
+                 ..f.. = fList,
 								data=localData,
 								# groups=eval(substitute(groups),localData),
 								groups=substitute(groups),
 								xlim=limits$xlim, 
 								xlab=xlab, ylab=ylab,
-								panel=panel.xyplot
-								),
+								panel="panel.plotFun1",
+                col=col ),
 								cleanDots
 								)
 			)
 		} else { 
 			thePlot <- do.call(lattice::xyplot, c(list(
 							    y ~ x,
+                  ..f.. = fList,
 								data=localData,
 								# groups=eval(substitute(groups),localData),
 								groups=substitute(groups),
 								xlim=limits$xlim, 
 								ylim=limits$ylim, 
 								xlab=xlab,ylab=ylab,
-								panel=panel.xyplot),
+								panel="panel.plotFun1",
+                col=col),
 								cleanDots)
 								)
 		}
-		return(thePlot)
+		return((thePlot))
 	}  # end ndims == 1
 
 	if (ndims == 2 ) {
+		# message("Two Dimensions.")
 		npts <- ifelse( is.null(npts), 40, npts)
 		if( length(ylab) == 0 ) ylab <- rhsVars[2]
 		if( length(xlab) == 0 ) xlab <- rhsVars[1]
@@ -249,7 +290,7 @@ plotFun <- function(object, ...,
 						   dist=slider(min=0,max=1,step=.01,initial=.2,label="Distance")
 						   ))
 			} else {  # without manipulate
-				return(wireframe(height ~ Var1 + Var2, 
+				return((wireframe(height ~ Var1 + Var2, 
 								 xlab=xlab,ylab=ylab,zlab=list(zlab,rot=90),
 								 data=grid,
 								 groups=eval(substitute(groups), localData),
@@ -258,37 +299,27 @@ plotFun <- function(object, ...,
 								 col.regions= zcolors,
 								 # col=rgb(1,1,1,0),
 								 at=zcuts
-								 ) )
+								 ) ) )
 			}
 
 		} else {  # i.e., surface==FALSE
 			# a convenience wrapper around levelplot when a contour plot
 			# is being drawn de novo
-			funPlot.draw.contour <- function(x,y,z,ncontours=6,at=NULL,
-											 filled=TRUE, col.regions=topo.colors,labels=TRUE,
-											 showlabels=TRUE, contours=TRUE, groups=NULL, label=TRUE,
-											 xlab="",ylab="", ...){
-        if (is.null(at)) at = pretty(z,ncontours)
-        argsToPass <- list(z~x*y,at=at, xlab=xlab,ylab=ylab,
-                          panel=panel.levelcontourplot,
-                          groups=substitute(groups),col.regions=col.regions(60),
-                          contour=contours, labels=labels, colorkey=FALSE,
-                          retion=TRUE, filled=filled, ...)
-        # kill off arguments we don't want going to levelplot:
-        argsToPass[["k"]] <- NULL
-        return( do.call( levelplot, argsToPass))                                                            
-# 				return(levelplot(z~x*y, at=at, 
-# 								 xlab=xlab, ylab=ylab, 
-# 								 panel=panel.levelcontourplot,
-# 								 groups=substitute(groups),
-# 								 col.regions=col.regions(60),
-# 								 contour=contours, labels=labels,
-# 								 colorkey = FALSE, region = TRUE, filled=filled,
-# 								 #col=col, 
-# 								 ... ) 
-# 				)
-			}
-
+		  funPlot.draw.contour <- function(x,y,z,ncontours=6,at=NULL,
+		                                   filled=TRUE, col.regions=topo.colors,labels=TRUE,
+		                                   showlabels=TRUE, contours=TRUE, groups=NULL, label=TRUE,
+		                                   xlab="",ylab="", ...){
+		    if (is.null(at)) at = pretty(z,ncontours)
+		    argsToPass <- list(z~x*y,at=at, xlab=xlab,ylab=ylab,
+		                       panel=panel.levelcontourplot,
+		                       groups=substitute(groups),col.regions=col.regions(60),
+		                       contour=contours, labels=labels, colorkey=FALSE,
+		                       retion=TRUE, filled=filled, ...)
+		    # kill off arguments we don't want going to levelplot:
+		    argsToPass[["k"]] <- NULL
+		    return(( do.call( levelplot, argsToPass) ))                                                           
+		  }
+		  
 			if( is.null(alpha) ) alpha <- 1
 			fillcolors <- col.regions (length(levels)+2, alpha=alpha)
 
@@ -296,18 +327,127 @@ plotFun <- function(object, ...,
 					fillcolors <- col.regions (4, alpha=alpha)
 				  nlevels <- 2
 			}
-			return(funPlot.draw.contour(grid$Var1, grid$Var2, grid$height, 
+      if (add) {
+        ladd( 
+          panel.levelcontourplot(grid$Var1, grid$Var2, grid$height, subscripts=1, 
+                          at = levels, labels = labels, 
+                          filled=filled, 
+                          groups=eval(substitute(groups),localData),
+                          col.regions = col.regions ,
+                          contour = TRUE, 
+                          region = FALSE, 
+                          ...)
+          )
+      }
+			return((funPlot.draw.contour(grid$Var1, grid$Var2, grid$height, 
 											 xlab=xlab, ylab=ylab, at=levels,
 											 filled=filled, labels=labels,
 											 groups=eval(substitute(groups),localData),
 											 col.regions = col.regions ,
 											 #col=col, 
-											 ...) )
+											 ...) ) )
 		}
 	}
 	stop("Bug alert: You should not get here.  Please report.")
 }
 
+
+#' Panel function for plotting functions
+#'
+#' @seealso plotFun
+#' @param ..f.. an object (e.g., a formula) describing a function
+#' @param x,y ignored, but there for compatibility with other lattice panel functions
+#' @param col a vector of colors
+#' @param npts an integer giving the number of points (in each dimension) to sample the function
+#' @param zlab label for z axis (when in surface-plot mode)
+#' @param filled fill with color between the contours (\code{TRUE} by default)
+#' @param levels levels at which to draw contours
+#' @param nlevels number of contours to draw (if \code{levels} not specified)
+#' @param surface a logical indicating whether to draw a surface plot rather than a contour plot
+#' @param type type of plot (\code{"l"} by default)
+#' @param alpha number from 0 (transparent) to 1 (opaque) for the fill colors 
+#' @param \dots additional arguments, typically processed by \code{lattice} panel functions
+#'        such as \code{\link[lattice]{panel.xyplot}} or \code{\link[lattice]{panel.levelplot}}.
+#'        Frequently used arguments include
+#'        \describe{
+#'          \item{\code{lwd}}{line width}
+#'        	\item{\code{lty}}{line type}
+#'        	\item{\code{col}}{a color}
+#'        }
+#'
+#' @examples
+#' x <- runif(30,0,2*pi) 
+#' d <- data.frame( x = x,  y = sin(x) + rnorm(30,sd=.2) )
+#' xyplot( y ~ x, data=d )
+#' ladd(panel.plotFun1( sin, col='red' ) )
+#' xyplot( y ~ x | rbinom(30,1,.5), data=d )
+#' ladd(panel.plotFun1( sin, col='red', lty=2 ) )    # plots sin(x) in each panel
+
+panel.plotFun1 <- function( ..f.., ...,
+                           x, y,
+                           type="l", 
+                           col = trellis.par.get('superpose.line')$col,
+                           npts=NULL,
+                           zlab=NULL, 
+                           filled=TRUE, 
+                           levels=NULL, 
+                           nlevels=10,
+                           surface=FALSE,
+                           alpha=NULL ) { 
+  dots <- list(...)
+
+  if (is.function(..f..) ) ..f.. <- list(..f..)
+  if (! is.list(..f..) || length(..f..) < 1) {
+    print(str(..f..))
+    stop("Empty or malformed list of functions.")
+  }
+  
+  if (is.numeric(col)) {
+    message('converting numerical color value into a color using lattice settings')
+    col <- trellis.par.get('superpose.line')$col[col]
+  }
+  
+    
+  # funny names (like ..f..) are to avoid names that might be used by the user
+  # not sure whether this precaution is necessary in current implementation
+  
+  # perhaps use environment(object)?
+  # ..f.. <- do.call( "makeFun", c(object, dots, strict.declaration=FALSE), envir= parent.frame())  
+  idx <- 0
+  
+  for ( .f. in ..f..) {  
+    idx <- idx + 1
+    # print(.f.)
+    vars <- formals(.f.)
+    #  rhsVars <- all.vars(rhs(object))
+    #  ndims <- length(rhsVars)
+    
+    parent.xlim <- current.panel.limits()$xlim
+    parent.ylim <- current.panel.limits()$ylim
+    
+    npts <- ifelse( is.null(npts), 200, npts)
+    
+    # Evaluate the function on appropriate inputs.
+    .xvals <-  if ('h' %in% type)  
+      seq(min(parent.xlim), max(parent.xlim), length.out=npts)
+    else 
+      adapt_seq(min(parent.xlim), max(parent.xlim), 
+                        f=function(xxqq){ .f.(xxqq) }, length.out=npts)
+    
+    .yvals <- sapply( .xvals, .f. ) 
+    
+    # need to strip out any components of ... that are in the object so they
+    # don't get passed to the panel function.
+    cleandots = list(...)
+    # cleandots[ intersect(names(cleandots), all.vars(object)) ] <- NULL
+    cleandots[c('x','y','type','alpha','col')] <- NULL
+    # use do.call to call the panel function so that the cleandots can be put back in
+    do.call(panel.xyplot,
+            c(list(x=.xvals, y=.yvals, type=type,  alpha=alpha, col=.getColor(idx,col)),  cleandots)
+    )
+  }
+}
+
 #' Panel function for plotting functions
 #'
 #' @seealso plotFun
@@ -325,7 +465,7 @@ plotFun <- function(object, ...,
 #'        such as \code{\link[lattice]{panel.xyplot}} or \code{\link[lattice]{panel.levelplot}}.
 #'        Frequently used arguments include
 #'        \describe{
-#'        	\item{\code{lwd}}{line width}
+#'          \item{\code{lwd}}{line width}
 #'        	\item{\code{lty}}{line type}
 #'        	\item{\code{col}}{a color}
 #'        }
@@ -338,74 +478,75 @@ plotFun <- function(object, ...,
 #' xyplot( y ~ x | rbinom(30,1,.5), data=d )
 #' ladd(panel.plotFun( sin(x) ~ x, col='red', lty=2 ) )    # plots sin(x) in each panel
 
+
 panel.plotFun <- function( object, ..., 
-						  type="l", 
-						  npts=NULL,
-						  zlab=NULL, 
-						  filled=TRUE, 
-						  levels=NULL, 
-						  nlevels=10,
-						  surface=FALSE,
-                   		  col.regions =topo.colors, 
-				   		  alpha=NULL ) { 
+                           type="l", 
+                           npts=NULL,
+                           zlab=NULL, 
+                           filled=TRUE, 
+                           levels=NULL, 
+                           nlevels=10,
+                           surface=FALSE,
+                           col.regions =topo.colors, 
+                           alpha=NULL ) { 
   dots <- list(...)
   if ( is.function(object) ) { 
-		formula <- f(x) ~ x 
-		formula[[2]] <- as.call( list(substitute(object), quote(x)))
-		object <- formula
-	}
-
+    formula <- f(x) ~ x 
+    formula[[2]] <- as.call( list(substitute(object), quote(x)))
+    object <- formula
+  }
+  
   if ( is.vector(col.regions ) ) col.regions  <- makeColorscheme(col.regions )
-
+  
   plot.line <- trellis.par.get('plot.line')
   superpose.line <- trellis.par.get('superpose.line')
- 
+  
   # funny names (like ..f..) are to avoid names that might be used by the user
   # not sure whether this precaution is necessary in current implementation
- 
+  
   # perhaps use environment(object)?
   ..f.. <- do.call( "makeFun", c(object, dots, strict.declaration=FALSE), envir= parent.frame())  
-
+  
   vars <- formals(..f..)
   rhsVars <- all.vars(rhs(object))
   ndims <- length(rhsVars)
- 
+  
   parent.xlim <- current.panel.limits()$xlim
   parent.ylim <- current.panel.limits()$ylim
-
+  
   if( ndims > 2 || ndims < 1 ) 
     stop("Formula must provide 1 or 2 independent variables (right hand side).")
-
+  
   if( ndims == 1 ){
-	  npts <- ifelse( is.null(npts), 200, npts)
-
-	  # Evaluate the function on appropriate inputs.
-	  .xvals <- 
-		  if ('h' %in% type)  
-			  seq(min(parent.xlim), max(parent.xlim), length.out=npts)
-			  else 
-				  mosaic::adapt_seq(min(parent.xlim), max(parent.xlim), 
-									f=function(xxqq){ ..f..(xxqq) }, length=npts)
-	  .yvals <- sapply( .xvals, ..f.. )  # pfun(.xvals)
-
-	  # need to strip out any components of ... that are in the object so they
-	  # don't get passed to the panel function.
-	  cleandots = list(...)
-	  cleandots[ names(cleandots) %in% all.vars(object) ] <- NULL
-	  # use do.call to call the panel function so that the cleandots can be put back in
+    npts <- ifelse( is.null(npts), 200, npts)
+    
+    # Evaluate the function on appropriate inputs.
+    .xvals <- 
+      if ('h' %in% type)  
+        seq(min(parent.xlim), max(parent.xlim), length.out=npts)
+    else 
+      adapt_seq(min(parent.xlim), max(parent.xlim), 
+                        f=function(xxqq){ ..f..(xxqq) }, length.out=npts)
+    .yvals <- sapply( .xvals, ..f.. )  # pfun(.xvals)
+    
+    # need to strip out any components of ... that are in the object so they
+    # don't get passed to the panel function.
+    cleandots = list(...)
+    cleandots[ names(cleandots) %in% all.vars(object) ] <- NULL
+    # use do.call to call the panel function so that the cleandots can be put back in
     return(do.call(panel.xyplot,c(list(x=.xvals, y=.yvals, type=type, alpha=alpha), cleandots)))
-	  #return(panel.xyplot(.xvals, .yvals, ...))
+    #return(panel.xyplot(.xvals, .yvals, ...))
   }
-	   
+  
   if (ndims == 2 ) {
     if( surface ) { 
-			stop('no add option for surface plots yet.')
-			return(NULL)
-	}
+      stop('no add option for surface plots yet.')
+      return(NULL)
+    }
     # if we get here, surface == FALSE & ndims=2
     npts <- ifelse( is.null(npts), 40, npts)
     # create a function of those two variables
-
+    
     if( length(zlab) == 0 ) zlab <- deparse(lhs(object) )
     
     .xvals <- seq(min(parent.xlim),max(parent.xlim),length=npts)
@@ -414,33 +555,37 @@ panel.plotFun <- function( object, ...,
     grid <- expand.grid( .xvals, .yvals )
     grid$height <- c(zvals)
     
-	zcuts <- pretty(grid$height,50)
-	zcolors <- col.regions (length(zcuts),alpha=.5)
-	# print(zcolors)
-	if( is.null(alpha) ) alpha<-.4
-
-	if( all(is.logical(zvals)) ) {  # it's a constraint function
-		#nlevels <- 2
-    levels <- c(0.0,Inf) 
-	}
-	fillcolors <- col.regions (length(levels) + 2, alpha=alpha)
-  if(is.null(levels)) levels=pretty(grid$height, nlevels)
-
-	return( panel.levelcontourplot(x = grid$Var1, y = grid$Var2, z = grid$height,
-						   subscripts = 1:nrow(grid),
-						   at = levels,
-						   col.regions = fillcolors,
-						   filled=filled, 
-						   ...
-						   #col=col, lwd = lwd, lty = 1,
-						   )
-	)
+    zcuts <- pretty(grid$height,50)
+    zcolors <- col.regions (length(zcuts),alpha=.5)
+    # print(zcolors)
+    if( is.null(alpha) ) alpha<-.4
+    
+    if( all(is.logical(zvals)) ) {  # it's a constraint function
+      #nlevels <- 2
+      levels <- c(0.0,Inf) 
+    }
+    fillcolors <- col.regions (length(levels) + 2, alpha=alpha)
+    if(is.null(levels)) levels=pretty(grid$height, nlevels)
+    
+    return( panel.levelcontourplot(x = grid$Var1, y = grid$Var2, z = grid$height,
+                                   subscripts = 1:nrow(grid),
+                                   at = levels,
+                                   col.regions = fillcolors,
+                                   filled=filled, 
+                                   ...
+                                   #col=col, lwd = lwd, lty = 1,
+    )
+    )
   }
   stop("Bug alert: You should not get here.  Please report.")
 }
 
 
 
+.getColor <- function( n=1, col=trellis.par.get('superpose.line')$col) {
+  if (length(col) < n) col <- rep(col, length.out=n)
+  col[n]
+}
 #' Infer arguments 
 #' 
 #' The primary purpose is for inferring argument settings from names derived from variables
@@ -510,7 +655,7 @@ inferArgs <- function( vars, dots, defaults=alist(xlim=, ylim=, zlim=), variants
 #' @param filled whether to fill the contours with color
 #' @param alpha.regions transparency of regions
 
-panel.levelcontourplot <- function(x, y, z, subscripts, 
+panel.levelcontourplot <- function(x, y, z, subscripts=1, 
                                    at, shrink, labels = TRUE, 
                                    label.style = c("mixed","flat","align"), 
                                    contour = FALSE, 
